# How to Contribute

We welcome all feedback you can provide in the form of GitHub issues, but this
library is widely used in our research code, so we are unlikely to be able
to accept changes without prior discussion. Feel free to contact us by opening
an issue to discuss the proposal before implementing the change.
